.. currentmodule:: disnake_compass

Component API
=============

.. automodule:: disnake_compass.api.component

Typing
------

.. autodata:: disnake_compass.api.component.ComponentT


Classes
-------

.. attributetable:: disnake_compass.api.component.RichComponent

.. autoclass:: disnake_compass.api.component.RichComponent
    :members:

.. attributetable:: disnake_compass.api.component.RichButton

.. autoclass:: disnake_compass.api.component.RichButton
    :members:

.. attributetable:: disnake_compass.api.component.RichSelect

.. autoclass:: disnake_compass.api.component.RichSelect
    :members:

.. attributetable:: disnake_compass.api.component.ComponentManager

.. autoclass:: disnake_compass.api.component.ComponentManager
    :members:

.. attributetable:: disnake_compass.api.component.ComponentFactory

.. autoclass:: disnake_compass.api.component.ComponentFactory
    :members:
